@@ -1,8 +1,12 @@
 from django.contrib.admin.helpers import ActionForm
-from django.utils.translation import ugettext_lazy as _
 
 from .fields import SemanticChoiceField
 
+try:
+    from django.utils.translation import gettext_lazy as _  # Django >= 4
+except ImportError:
+    from django.utils.translation import ugettext_lazy as _
+
 
 class SemanticActionForm(ActionForm):
     action = SemanticChoiceField(label=_("Action:"))
